@@ -79,7 +79,7 @@ if (getenv('PHP_PEAR_HTTP_PROXY')) {
 if (getenv('PHP_PEAR_INSTALL_DIR')) {
     define('PEAR_CONFIG_DEFAULT_PHP_DIR', getenv('PHP_PEAR_INSTALL_DIR'));
 } else {
-    define('PEAR_CONFIG_DEFAULT_PHP_DIR', '/var/www/pear'.'/lib');
+    define('PEAR_CONFIG_DEFAULT_PHP_DIR', '/var/www/pear/lib');
 }
 
 // Default for metadata_dir
@@ -255,7 +255,7 @@ if (getenv('PHP_PEAR_SIG_KEYDIR')) {
  * @author     Greg Beaver <cellog@php.net>
  * @copyright  1997-2009 The Authors
  * @license    http://opensource.org/licenses/bsd-license.php New BSD License
- * @version    Release: 1.10.12
+ * @version    Release: 1.10.15
  * @link       http://pear.php.net/package/PEAR
  * @since      Class available since Release 0.1
  */
@@ -718,7 +718,7 @@ class PEAR_Config extends PEAR
 
         $t_conf = new PEAR_Config($user_file, $system_file, false, $strict);
         if ($t_conf->_errorsFound > 0) {
-             return $t_conf->lastError;
+             return $t_conf->_lastError;
         }
 
         $GLOBALS['_PEAR_Config_instance'] = &$t_conf;
@@ -766,7 +766,7 @@ class PEAR_Config extends PEAR
             }
 
             $this->_errorsFound++;
-            $this->lastError = $data;
+            $this->_lastError = $data;
 
             return $data;
         }
@@ -919,7 +919,7 @@ class PEAR_Config extends PEAR
             }
 
             $this->_errorsFound++;
-            $this->lastError = $data;
+            $this->_lastError = $data;
 
             return $data;
         }
