@@ -29,7 +29,7 @@ $GLOBALS['_PEAR_DEPENDENCYDB_INSTANCE'] = array();
  * @author     Tomas V.V.Cox <cox@idec.net.com>
  * @copyright  1997-2009 The Authors
  * @license    http://opensource.org/licenses/bsd-license.php New BSD License
- * @version    Release: 1.10.7
+ * @version    Release: 1.10.15
  * @link       http://pear.php.net/package/PEAR
  * @since      Class available since Release 1.4.0a1
  */
@@ -174,7 +174,7 @@ class PEAR_DependencyDB
             $this->rebuildDB();
         }
 
-        if ($depdb['_version']{0} > $this->_version{0}) {
+        if ($depdb['_version'][0] > $this->_version[0]) {
             return PEAR::raiseError('Dependency database is version ' .
                 $depdb['_version'] . ', and we are version ' .
                 $this->_version . ', cannot continue');
@@ -216,9 +216,11 @@ class PEAR_DependencyDB
         if (is_object($pkg)) {
             $channel = strtolower($pkg->getChannel());
             $package = strtolower($pkg->getPackage());
-        } else {
+        } else if (is_array($pkg)) {
             $channel = strtolower($pkg['channel']);
             $package = strtolower($pkg['package']);
+        } else {
+            return false;
         }
 
         $depend = $this->getDependentPackages($pkg);
@@ -499,8 +501,9 @@ class PEAR_DependencyDB
         }
 
         if (!is_resource($this->_lockFp)) {
+            $last_errormsg = error_get_last();
             return PEAR::raiseError("could not create Dependency lock file" .
-                                     (isset($php_errormsg) ? ": " . $php_errormsg : ""));
+                                     (isset($last_errormsg) ? ": " . $last_errormsg : ""));
         }
 
         if (!(int)flock($this->_lockFp, $mode)) {
