@@ -35,7 +35,7 @@ define('PEAR_INSTALLER_NOBINARY', -240);
  * @author     Greg Beaver <cellog@php.net>
  * @copyright  1997-2009 The Authors
  * @license    http://opensource.org/licenses/bsd-license.php New BSD License
- * @version    Release: 1.10.12
+ * @version    Release: 1.10.15
  * @link       http://pear.php.net/package/PEAR
  * @since      Class available since Release 0.1
  */
@@ -1271,7 +1271,7 @@ class PEAR_Installer extends PEAR_Downloader
                 if (count($test)) {
                     $msg = "$channel/$pkgname: conflicting files found:\n";
                     $longest = max(array_map("strlen", array_keys($test)));
-                    $fmt = "%${longest}s (%s)\n";
+                    $fmt = "%{$longest}s (%s)\n";
                     foreach ($test as $file => $info) {
                         if (!is_array($info)) {
                             $info = array('pear.php.net', $info);
@@ -1529,11 +1529,11 @@ class PEAR_Installer extends PEAR_Downloader
         foreach ($built as $ext) {
             $bn = basename($ext['file']);
             list($_ext_name, $_ext_suff) = explode('.', $bn);
-            if ($_ext_suff == '.so' || $_ext_suff == '.dll') {
+            if ($_ext_suff == 'so' || $_ext_suff == 'dll') {
                 if (extension_loaded($_ext_name)) {
-                    $this->raiseError("Extension '$_ext_name' already loaded. " .
-                                      'Please unload it in your php.ini file ' .
-                                      'prior to install or upgrade');
+                    return $this->raiseError("Extension '$_ext_name' already loaded. " .
+                                             'Please unload it in your php.ini file ' .
+                                             'prior to install or upgrade');
                 }
                 $role = 'ext';
             } else {
