@@ -50,7 +50,7 @@ $GLOBALS['_System_temp_files'] = array();
 * @author     Tomas V.V. Cox <cox@idecnet.com>
 * @copyright  1997-2006 The PHP Group
 * @license    http://opensource.org/licenses/bsd-license.php New BSD License
-* @version    Release: 1.10.12
+* @version    Release: 1.10.15
 * @link       http://pear.php.net/package/PEAR
 * @since      Class available since Release 0.1
 * @static
@@ -530,7 +530,9 @@ class System
                 // It's possible to run a .bat on Windows that is_executable
                 // would return false for. The is_executable check is meaningless...
                 if (OS_WINDOWS) {
-                    return $file;
+                    if (file_exists($file)) {
+                        return $file;
+                    }
                 } else {
                     if (is_executable($file)) {
                         return $file;
