@@ -42,7 +42,7 @@ ob_implicit_flush(true);
 $_PEAR_PHPDIR = '#$%^&*';
 set_error_handler('error_handler');
 
-$pear_package_version = "1.10.12";
+$pear_package_version = "1.10.15";
 
 require_once 'PEAR.php';
 require_once 'PEAR/Frontend.php';
@@ -54,13 +54,6 @@ require_once 'Console/Getopt.php';
 PEAR_Command::setFrontendType('CLI');
 $all_commands = PEAR_Command::getCommands();
 
-// remove this next part when we stop supporting that crap-ass PHP 4.2
-if (!isset($_SERVER['argv']) && !isset($argv) && !isset($HTTP_SERVER_VARS['argv'])) {
-    echo 'ERROR: either use the CLI php executable, ' .
-         'or set register_argc_argv=On in php.ini';
-    exit(1);
-}
-
 $argv = Console_Getopt::readPHPArgv();
 // fix CGI sapi oddity - the -- in pear.bat/pear is not removed
 if (php_sapi_name() != 'cli' && isset($argv[1]) && $argv[1] == '--') {
